@@ -1,10 +1,8 @@
 """
-	Impossible FX Render API
-	API Version: 2016-06-02
-	Generated: timestamp
+Impossible FX Render API
 
-	Please send suggestions and bug reports to:
-	python-sdk@impossiblesoftware.com
+Please send suggestions and bug reports to:
+python-sdk@impossiblesoftware.com
 """
 
 import json
@@ -27,10 +25,6 @@ class RenderService( FXService ):
 		**kwargs	# internal use, e.g. debug=True
 	):
 		"""
-		Impossible FX Render API
-
-		API Version 2016-06-02
-
 		:param region: 		Region for requests
 		:type region:		str
 
@@ -40,15 +34,15 @@ class RenderService( FXService ):
 		:param max_retries:	maximum number of retries for failed connections
 		:type max_retries:	int
 
-		:param auth:		'requests' authenticator
-		:type auth:			(APIkey, APIsecret) or requests.auth.AuthBase or descendants
+		:param auth:		API key and API secret, required for ProjectService, not for RenderService
+		:type auth:			tuple of strings
 		"""
 
 		FXService.__init__( self, region, response_timeout, max_retries, auth, **kwargs )
 		if region is None:
 		    if globalEndpoint is None:
 		        raise ValueError, "This service requires a specific region"
-		    self.config["endpoint_mask"] = "'render.impossible.io'"
+		    self.config["endpoint_mask"] = "'render.impossible.io'".replace("'", "")
 		else:
 			self.config["endpoint_mask"] = "render-{region}.impossible.io"
 
@@ -57,13 +51,13 @@ class RenderService( FXService ):
 		"""
 		GetToken: Create a render token
 
-		:param project_id: A Project ID <b>(required)</b>
+		:param project_id: A Project ID (required)
 		:type project_id: str
 
-		:param movie_name: Movie to render <b>(required)</b>
+		:param movie_name: Movie to render (required)
 		:type movie_name: str
 
-		:param params: Render Parameters <b>(required)</b>
+		:param params: Render Parameters (required)
 		:type params: dict
 		"""
 		_input = {'project_id': project_id, 'movie_name': movie_name, 'params': params}
@@ -81,22 +75,22 @@ class RenderService( FXService ):
 		"""
 		GetRenderURL: Create a render URL
 
-		:param project_id: A Project ID <b>(required)</b>
+		:param project_id: A Project ID (required)
 		:type project_id: str
 
-		:param movie_name: Movie to render <b>(required)</b>
+		:param movie_name: Movie to render (required)
 		:type movie_name: str
 
-		:param params: Render Parameters <b>(required)</b>
+		:param params: Render Parameters (required)
 		:type params: dict
 
-		:param endpoint: Render Endpoint (default: <code>'https://render.impossible.io'</code>)
+		:param endpoint: Render Endpoint (default: 'https://render.impossible.io')
 		:type endpoint: str
 
-		:param mode: Render Mode (default: <code>'render'</code>)
+		:param mode: Render Mode (default: 'render')
 		:type mode: str
 
-		:param format: Format of video (default: <code>'mp4'</code>)
+		:param format: Format of video (default: 'mp4')
 		:type format: str
 		"""
 		_input = {'project_id': project_id, 'movie_name': movie_name, 'params': params, 'endpoint': endpoint, 'mode': mode, 'format': format}
@@ -114,25 +108,25 @@ class RenderService( FXService ):
 		"""
 		GetPosterFrameURL: Create a render URL
 
-		:param project_id: A Project ID <b>(required)</b>
+		:param project_id: A Project ID (required)
 		:type project_id: str
 
-		:param movie_name: Movie to render <b>(required)</b>
+		:param movie_name: Movie to render (required)
 		:type movie_name: str
 
-		:param params: Render Parameters <b>(required)</b>
+		:param params: Render Parameters (required)
 		:type params: dict
 
-		:param frame: Frame Number <b>(required)</b>
+		:param frame: Frame Number (required)
 		:type frame: int
 
-		:param endpoint: Render Endpoint (default: <code>'https://render.impossible.io'</code>)
+		:param endpoint: Render Endpoint (default: 'https://render.impossible.io')
 		:type endpoint: str
 
-		:param mode: Render Mode (default: <code>'render'</code>)
+		:param mode: Render Mode (default: 'render')
 		:type mode: str
 
-		:param format: Format of image (jpg|png) (default: <code>'jpg'</code>)
+		:param format: Format of image (jpg|png) (default: 'jpg')
 		:type format: str
 		"""
 		_input = {'project_id': project_id, 'movie_name': movie_name, 'params': params, 'frame': frame, 'endpoint': endpoint, 'mode': mode, 'format': format}
@@ -148,29 +142,29 @@ class RenderService( FXService ):
 		return result
 
 
-	def render_to_s3( self, project_id, movie_name, params, format, bucket, filename, type=None, async=None, use_policy=None, access_key_id=None, secret_access_key=None, content_type=None, content_disposition=None, acl=None, cache_control=None, secure=None, s3_host=None, reduced_redundancy=None ) :
+	def render_to_s3( self, project_id, movie_name, params, format, bucket, filename, type='s3', async=None, use_policy=None, access_key_id=None, secret_access_key=None, content_type=None, content_disposition=None, acl=None, cache_control=None, secure=None, s3_host=None, reduced_redundancy=None ) :
 		"""
 		RenderToS3: This operation renders a video and uploads the file to Amazon S3
 
-		:param project_id: A Project ID <b>(required)</b>
+		:param project_id: A Project ID (required)
 		:type project_id: str
 
-		:param movie_name: Movie to render <b>(required)</b>
+		:param movie_name: Movie to render (required)
 		:type movie_name: str
 
-		:param params: Render Parameters <b>(required)</b>
+		:param params: Render Parameters (required)
 		:type params: dict
 
-		:param format: Format to Render <b>(required)</b>
+		:param format: Format to Render (required)
 		:type format: str
 
-		:param bucket: S3 Bucket Name <b>(required)</b>
+		:param bucket: S3 Bucket Name (required)
 		:type bucket: str
 
-		:param filename: S3 Filename <b>(required)</b>
+		:param filename: S3 Filename (required)
 		:type filename: str
 
-		:param type:  (optional)
+		:param type:  (default: 's3')
 		:type type: str
 
 		:param async: Perform Async (optional)
@@ -234,32 +228,32 @@ class RenderService( FXService ):
 		return result
 
 
-	def render_to_azure( self, project_id, movie_name, params, format, account, container, key, type=None, async=None, content_type=None ) :
+	def render_to_azure( self, project_id, movie_name, params, format, account, container, key, type='azureblob', async=None, content_type=None ) :
 		"""
 		RenderToAzure: This operation renders a video and uploads the file to Microsoft Azure Blob Storage
 
-		:param project_id: A Project ID <b>(required)</b>
+		:param project_id: A Project ID (required)
 		:type project_id: str
 
-		:param movie_name: Movie to render <b>(required)</b>
+		:param movie_name: Movie to render (required)
 		:type movie_name: str
 
-		:param params: Render Parameters <b>(required)</b>
+		:param params: Render Parameters (required)
 		:type params: dict
 
-		:param format: Format to Render <b>(required)</b>
+		:param format: Format to Render (required)
 		:type format: str
 
-		:param account: Storage account name <b>(required)</b>
+		:param account: Storage account name (required)
 		:type account: str
 
-		:param container: Name of storage container <b>(required)</b>
+		:param container: Name of storage container (required)
 		:type container: str
 
-		:param key: Filename for the destination object <b>(required)</b>
+		:param key: Filename for the destination object (required)
 		:type key: str
 
-		:param type:  (optional)
+		:param type:  (default: 'azureblob')
 		:type type: str
 
 		:param async: Perform Async (optional)
@@ -288,32 +282,32 @@ class RenderService( FXService ):
 		return result
 
 
-	def render_to_youtube( self, project_id, movie_name, params, format, title, description, category, type=None, async=None, o_auth_access_token=None, auth_secret=None, status=None, tags=None, playlist_id=None, notify_subscribers=None ) :
+	def render_to_youtube( self, project_id, movie_name, params, format, title, description, category, type='youtube', async=None, o_auth_access_token=None, auth_secret=None, status=None, tags=None, playlist_id=None, notify_subscribers=None ) :
 		"""
 		RenderToYoutube: This operation renders a video and uploads the video to Youtube
 
-		:param project_id: A Project ID <b>(required)</b>
+		:param project_id: A Project ID (required)
 		:type project_id: str
 
-		:param movie_name: Movie to render <b>(required)</b>
+		:param movie_name: Movie to render (required)
 		:type movie_name: str
 
-		:param params: Render Parameters <b>(required)</b>
+		:param params: Render Parameters (required)
 		:type params: dict
 
-		:param format: Format to Render <b>(required)</b>
+		:param format: Format to Render (required)
 		:type format: str
 
-		:param title: Video title <b>(required)</b>
+		:param title: Video title (required)
 		:type title: str
 
-		:param description: Video description <b>(required)</b>
+		:param description: Video description (required)
 		:type description: str
 
-		:param category: Numerical ID for category. See List of <a href=" https://www.impossiblesoftware.com/docs/rendering/uploading/youtube.html#categories">Youtube Categories</a> <b>(required)</b>
+		:param category: Numerical ID for category. See List of <a href=" https://www.impossiblesoftware.com/docs/rendering/uploading/youtube.html#categories">Youtube Categories</a> (required)
 		:type category: str
 
-		:param type:  (optional)
+		:param type:  (default: 'youtube')
 		:type type: str
 
 		:param async: Perform Async (optional)
@@ -362,26 +356,26 @@ class RenderService( FXService ):
 		return result
 
 
-	def render_to_facebook( self, project_id, movie_name, params, format, o_auth_access_token, type=None, async=None, title=None, description=None, caption=None, name=None ) :
+	def render_to_facebook( self, project_id, movie_name, params, format, o_auth_access_token, type='facebook', async=None, title=None, description=None, caption=None, name=None ) :
 		"""
 		RenderToFacebook: This operation renders a video and uploads the video to Facebook
 
-		:param project_id: A Project ID <b>(required)</b>
+		:param project_id: A Project ID (required)
 		:type project_id: str
 
-		:param movie_name: Movie to render <b>(required)</b>
+		:param movie_name: Movie to render (required)
 		:type movie_name: str
 
-		:param params: Render Parameters <b>(required)</b>
+		:param params: Render Parameters (required)
 		:type params: dict
 
-		:param format: Format to Render <b>(required)</b>
+		:param format: Format to Render (required)
 		:type format: str
 
-		:param o_auth_access_token: Facebook OAuth 2.0 access token <b>(required)</b>
+		:param o_auth_access_token: Facebook OAuth 2.0 access token (required)
 		:type o_auth_access_token: str
 
-		:param type:  (optional)
+		:param type:  (default: 'facebook')
 		:type type: str
 
 		:param async: Perform Async (optional)
@@ -420,32 +414,32 @@ class RenderService( FXService ):
 		return result
 
 
-	def render_to_dropbox( self, project_id, movie_name, params, format, o_auth_access_token, auth_secret, filename, type=None, async=None ) :
+	def render_to_dropbox( self, project_id, movie_name, params, format, o_auth_access_token, auth_secret, filename, type='facebook', async=None ) :
 		"""
 		RenderToDropbox: This operation renders a video and uploads the video to Dropbox
 
-		:param project_id: A Project ID <b>(required)</b>
+		:param project_id: A Project ID (required)
 		:type project_id: str
 
-		:param movie_name: Movie to render <b>(required)</b>
+		:param movie_name: Movie to render (required)
 		:type movie_name: str
 
-		:param params: Render Parameters <b>(required)</b>
+		:param params: Render Parameters (required)
 		:type params: dict
 
-		:param format: Format to Render <b>(required)</b>
+		:param format: Format to Render (required)
 		:type format: str
 
-		:param o_auth_access_token: Facebook OAuth 2.0 access token <b>(required)</b>
+		:param o_auth_access_token: Facebook OAuth 2.0 access token (required)
 		:type o_auth_access_token: str
 
-		:param auth_secret: Impossible FX auth secret <b>(required)</b>
+		:param auth_secret: Impossible FX auth secret (required)
 		:type auth_secret: str
 
-		:param filename: Filename for uploaded video <b>(required)</b>
+		:param filename: Filename for uploaded video (required)
 		:type filename: str
 
-		:param type:  (optional)
+		:param type:  (default: 'facebook')
 		:type type: str
 
 		:param async: Perform Async (optional)
